@@ -901,9 +901,9 @@ void EventSheet::runScript(QString name)
 	QString outFileName = "qutesheet_out_data.txt";
 	QDir oldDir = QDir::current();
 	QDir tempDir(QDir::tempPath());
-	QString subDir = "QCS-" + QString::number(qrand());
+    QString subDir = "QCS-" + QString::number(QRandomGenerator::global()->generate());
 	while (!tempDir.mkdir(subDir))
-		subDir = "QCS-" + QString(qrand());
+        subDir = "QCS-" + QString(QRandomGenerator::global()->generate());
 	tempDir.cd(subDir);
 	QDir::setCurrent(tempDir.absolutePath());
 	QFile module(tempDir.absolutePath() + QDir::separator() + "qutesheet.py");
@@ -934,6 +934,7 @@ void EventSheet::runScript(QString name)
 	QFile outFile(tempDir.absolutePath() + QDir::separator() + outFileName);
 
 	QProcess p;
+    // TODO: fix this
 	p.start("python " + name.mid(name.lastIndexOf("/") + 1));
 
 	while (!p.waitForFinished (10) && !m_stopScript) {
@@ -1052,7 +1053,8 @@ void EventSheet::deleteRows()
 			selectedRows.append(list[i].row());
 		}
 	}
-	qSort(selectedRows);
+    std::sort(selectedRows.begin(), selectedRows.end());
+    // qSort(selectedRows);
 	for (int i = selectedRows.size() - 1; i >=0; i--) {
 		this->removeRow(selectedRows[i]);
 	}
@@ -1234,9 +1236,7 @@ void EventSheet::randomize(double min, double max, int mode)
 	// Mode 0 =
 	// Mode 1 = integers only
 	QModelIndexList list = this->selectedIndexes();
-	QTime midnight(0, 0, 0);
-	qsrand(midnight.secsTo(QTime::currentTime()));
-	for (int i = 0; i < list.size(); i++) {
+    for (int i = 0; i < list.size(); i++) {
 		QTableWidgetItem * item = this->item(list[i].row(), list[i].column());
 		if (item == 0) {
 			item = new QTableWidgetItem();
@@ -1245,10 +1245,10 @@ void EventSheet::randomize(double min, double max, int mode)
 		}
 		double value = 0.0;
 		if (mode == 0) {
-			value = min + ((double) qrand() / (double) RAND_MAX) * (max - min);
+            value = min + ((double) QRandomGenerator::global()->generate() / (double)QRandomGenerator::max()) * (max - min);
 		}
 		else /*if (mode == 1)*/ {  // Integers only
-			value = min + (qrand() % (int) (max - min + 1)); // Include max value as a possibility
+            value = min + (QRandomGenerator::global()->generate() % static_cast<int>(max - min + 1)); // Include max value as a possibility
 		}
 		noHistoryChange = 1;
 		item->setData(Qt::DisplayRole,
@@ -1261,16 +1261,16 @@ void EventSheet::randomize(double min, double max, int mode)
 void EventSheet::shuffle(int iterations)
 {
 	QTime midnight(0, 0, 0);
-	qsrand(midnight.secsTo(QTime::currentTime()));
-	QModelIndexList list = this->selectedIndexes();
+    QModelIndexList list = this->selectedIndexes();
+    auto rnd = QRandomGenerator::global();
 	if (list.size() < 3)
 		return;
 	for (int i = 0; i < iterations; i++) { // First traverse to copy values
-		int num1 = qrand() % list.size();
+        int num1 = rnd->generate() % list.size();
 		QTableWidgetItem * item1 = this->item(list[num1].row(), list[num1].column());
-		int num2 = qrand() % list.size();
+        int num2 = rnd->generate() % list.size();
 		while (num2 == num1) {
-			num2 = qrand() % list.size();
+            num2 = rnd->generate() % list.size();
 		}
 		QTableWidgetItem * item2 = this->item(list[num2].row(), list[num2].column());
 		QVariant value1 = QVariant();
