@@ -60,20 +60,21 @@ inline CsoundEngineStatus csoundEngineStatus(CsoundUserData *ud) {
 QuteGraph::QuteGraph(QWidget *parent) : QuteWidget(parent)
 {
 	m_widget = new StackedLayoutWidget(this);
-	m_widget->show();
-	//  m_widget->setAutoFillBackground(true);
-	m_widget->setMouseTracking(true); // Necessary to pass mouse tracking to widget panel for _MouseX channels
-	m_widget->setContextMenuPolicy(Qt::NoContextMenu);
+    //  m_widget->setAutoFillBackground(true);
+    // m_widget->show();
+
     m_numticksY = 6;
 	m_label = new QLabel(this);
 	QPalette palette = m_widget->palette();
     palette.setColor(QPalette::WindowText, QColor(150, 150, 150));
 	m_label->setPalette(palette);
-	m_label->setText("");
+    // m_label->setText("");
     m_label->setFont(QFont({"Helvetica", 7}));
     m_label->move(120, -4);
 	m_label->resize(500, 25);
-	m_pageComboBox = new QComboBox(this);
+    m_label->setFocusPolicy(Qt::NoFocus);
+
+    m_pageComboBox = new QComboBox(this);
     m_pageComboBox->setMinimumWidth(120);
     m_pageComboBox->setMaximumHeight(14);
     m_pageComboBox->setFont(QFont({"Sans", 7}));
@@ -82,7 +83,6 @@ QuteGraph::QuteGraph(QWidget *parent) : QuteWidget(parent)
                                   "{ min-width: 150px; }");
     // m_pageComboBox->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
     m_pageComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
-	m_label->setFocusPolicy(Qt::NoFocus);
     m_drawGrid = true;
     m_drawTableInfo = true;
     m_showScrollbars = true;
@@ -96,6 +96,7 @@ QuteGraph::QuteGraph(QWidget *parent) : QuteWidget(parent)
     Pal.setColor(QPalette::Background, Qt::black);
     this->setAutoFillBackground(true);
     this->setPalette(Pal);
+    this->setStyleSheet("QFrame { border: 0px; }");
 
 	// Default properties
 	setProperty("QCS_zoomx", 1.0);
@@ -121,6 +122,11 @@ QuteGraph::QuteGraph(QWidget *parent) : QuteWidget(parent)
     m_frozen = false;
     m_getPeakChannel = "";
     m_peakChannelPtr = nullptr;
+
+    m_widget->setMouseTracking(true); // Necessary to pass mouse tracking to widget panel for _MouseX channels
+    m_widget->setContextMenuPolicy(Qt::NoContextMenu);
+    m_widget->show();
+
 }
 
 QuteGraph::~QuteGraph()
@@ -350,7 +356,7 @@ void QuteGraph::setValue(double value)
 void QuteGraph::setValue(QString text)
 {
     bool ok;
-    auto parts = text.splitRef(' ', QString::SkipEmptyParts);
+    auto parts = text.splitRef(' ', SKIP_EMPTY_PARTS);
     if(parts[0] == "@set") {
         bool ok;
         int index = parts[1].toInt(&ok);
@@ -528,6 +534,7 @@ void QuteGraph::refreshWidget()
 
 void QuteGraph::createPropertiesDialog()
 {
+    QLabel *label;
 	QuteWidget::createPropertiesDialog();
 	dialog->setWindowTitle("Graph");
 
@@ -535,27 +542,23 @@ void QuteGraph::createPropertiesDialog()
 	channelLabel->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 	//  nameLineEdit->setText(getChannelName());
 
-	QLabel *label = new QLabel(dialog);
-	label = new QLabel(dialog);
-	label->setText("F-table Channel name =");
-	layout->addWidget(label, 4, 0, Qt::AlignRight|Qt::AlignVCenter);
+    label = new QLabel("F-table Channel name =", dialog);
+    layout->addWidget(label, 4, 0, Qt::AlignRight|Qt::AlignVCenter);
 	name2LineEdit = new QLineEdit(dialog);
 	name2LineEdit->setText(getChannel2Name());
 	name2LineEdit->setMinimumWidth(320);
 	layout->addWidget(name2LineEdit, 4,1,1,3, Qt::AlignLeft|Qt::AlignVCenter);
 
-	label = new QLabel(dialog);
-	label->setText("Zoom X");
-	layout->addWidget(label, 8, 0, Qt::AlignRight|Qt::AlignVCenter);
+    label = new QLabel("Zoom X", dialog);
+    layout->addWidget(label, 8, 0, Qt::AlignRight|Qt::AlignVCenter);
 	zoomxBox = new QDoubleSpinBox(dialog);
 	zoomxBox->setRange(0.1, 10.0);
 	zoomxBox->setDecimals(1);
 	zoomxBox->setSingleStep(0.1);
 	layout->addWidget(zoomxBox, 8, 1, Qt::AlignLeft|Qt::AlignVCenter);
 
-	label = new QLabel(dialog);
-	label->setText("Zoom Y");
-	layout->addWidget(label, 8, 2, Qt::AlignRight|Qt::AlignVCenter);
+    label = new QLabel("Zoom Y", dialog);
+    layout->addWidget(label, 8, 2, Qt::AlignRight|Qt::AlignVCenter);
 	zoomyBox = new QDoubleSpinBox(dialog);
 	zoomyBox->setRange(0.1, 10.0);
 	zoomyBox->setDecimals(1);
@@ -581,26 +584,22 @@ void QuteGraph::createPropertiesDialog()
     acceptDisplaysCheckBox->setChecked(property("QCS_enableDisplays").toBool());
     layout->addWidget(acceptDisplaysCheckBox, 9, 1, Qt::AlignLeft|Qt::AlignVCenter);
 
-    showSelectorCheckBox = new QCheckBox(dialog);
-    showSelectorCheckBox->setText("Show Selector");
+    showSelectorCheckBox = new QCheckBox("Show Selector", dialog);
     showSelectorCheckBox->setChecked(property("QCS_showSelector").toBool());
     layout->addWidget(showSelectorCheckBox, 10, 0, Qt::AlignLeft|Qt::AlignVCenter);
 
-    showGridCheckBox = new QCheckBox(dialog);
-    showGridCheckBox->setText("Show Grid");
+    showGridCheckBox = new QCheckBox("Show Grid", dialog);
     showGridCheckBox->setChecked(property("QCS_showGrid").toBool());
     showGridCheckBox->setToolTip("Show the grid. Has effect only for spectral graphs");
     layout->addWidget(showGridCheckBox, 10, 1, Qt::AlignLeft|Qt::AlignVCenter);
 
-    showTableInfoCheckBox = new QCheckBox(dialog);
-    showTableInfoCheckBox->setText("Show Table Information");
+    showTableInfoCheckBox = new QCheckBox("Show Table Information", dialog);
     showTableInfoCheckBox->setCheckState(
                 property("QCS_showTableInfo").toBool()?Qt::Checked:Qt::Unchecked);
     showTableInfoCheckBox->setToolTip("Show the grid. Has effect only for spectral graphs");
     layout->addWidget(showTableInfoCheckBox, 11, 0, Qt::AlignLeft|Qt::AlignVCenter);
 
-    showScrollbarsCheckBox = new QCheckBox(dialog);
-    showScrollbarsCheckBox->setText("Show Scrollbars");
+    showScrollbarsCheckBox = new QCheckBox("Show Scrollbars", dialog);
     showScrollbarsCheckBox->setChecked(property("QCS_showScrollbars").toBool());
     layout->addWidget(showScrollbarsCheckBox, 11, 1, Qt::AlignLeft|Qt::AlignVCenter);
 
@@ -849,6 +848,7 @@ void QuteGraph::addCurve(Curve * curve)
     scene->addItem(markerText);
     m_spectrumPeakTexts.append(markerText);
     m_dbRange = 100;
+    auto gridTextFont = QFont("Sans", 6);
 
     if(graphType == GraphType::GRAPH_SPECTRUM) {
         for (int i = 0 ; i < numTicksY; i++) {
@@ -863,7 +863,7 @@ void QuteGraph::addCurve(Curve * curve)
             int dbs = round(float(i)/numTicksY * 120.0);
             gridText->setHtml(QString("<div style=\"background:#000000;\">-%1 </p>"
                                       ).arg(dbs));
-            gridText->setFont(QFont("Sans", 6));
+            gridText->setFont(gridTextFont);
             gridText->setVisible(false);
             scene->addItem(gridText);
             gridTextVectorY.append(gridText);
@@ -891,7 +891,7 @@ void QuteGraph::addCurve(Curve * curve)
                                 .arg(kHz, 2, 'f', 1));
 
             }
-            gridText->setFont(QFont("Sans", 6));
+            gridText->setFont(gridTextFont);
             gridText->setVisible(false);
             scene->addItem(gridText);
             gridTextVectorX.append(gridText);
@@ -1031,7 +1031,8 @@ void QuteGraph::drawFtablePath(Curve *curve, int index) {
     if (decimate == 0) {
         decimate = 1;
     }
-    auto pen = QPen(QColor(255, 45, 7), 0);
+    auto pen = QPen(QColor(255, 255, 50), 0);
+    // auto pen = QPen(QColor(255, 45, 7), 0);
 
     auto rect = this->rect();
     int width = rect.width();
@@ -1117,7 +1118,7 @@ void QuteGraph::drawSpectrumPath(Curve *curve, int index) {
         int step = 1000;
         int numTicksX = nyquist / step;
         int numTicksY = 7;
-        printf("grid: nyquist: %d, numticks: %d\n", nyquist, numTicksX);
+        // printf("grid: nyquist: %d, numticks: %d\n", nyquist, numTicksX);
 
         auto gridPen = QPen(QColor(40, 40, 40));
         gridPen.setCosmetic(true);
@@ -1258,7 +1259,6 @@ void QuteGraph::freezeSpectrum(bool status) {
     } else {
         m_frozen = false;
     }
-
 }
 
 void QuteGraph::drawSpectrum(Curve *curve, int index) {
@@ -1267,7 +1267,7 @@ void QuteGraph::drawSpectrum(Curve *curve, int index) {
     int curveSize = curve->get_size();
     if(curveSize != frozenCurve.size() && graphtypes[index] == GraphType::GRAPH_SPECTRUM)
         freezeSpectrum(false);
-    auto view = getView(index);
+    // auto view = getView(index);
     // QGraphicsScene *scene = static_cast<QGraphicsView *>(static_cast<StackedLayoutWidget *>(m_widget)->widget(index))->scene();
     QVector<QPointF> polygonPoints;
     polygonPoints.resize(curveSize + 2);
@@ -1400,7 +1400,7 @@ void QuteGraph::drawSpectrum(Curve *curve, int index) {
             notename = mton(midinote);
         }
         else {
-            midinote = 0;
+            // midinote = 0;
             notename = "LOW";
         }
         markerText->setPlainText(QString("%1 Hz (%2)").arg((int)(peakFreq+0.5)).arg(notename));
@@ -1551,7 +1551,11 @@ void QuteTableWidget::reset() {
         m_maxy = 1.0;
         m_miny = -1.0;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
     m_path.clear();
+#else
+    m_path = QPainterPath(); // not sure if it works
+#endif
 }
 
 
@@ -1701,7 +1705,11 @@ void QuteTableWidget::updatePath() {
         miny = m_miny = floor(newminy);
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
     m_path.clear();
+#else
+    m_path = QPainterPath(); // not sure if it works
+#endif
     QPolygonF poly;
     double yscale = -height / (maxy-miny);
 
@@ -1935,7 +1943,7 @@ void QuteTable::setValue(double value) {
 };
 
 void QuteTable::setValue(QString s) {
-    auto parts = s.splitRef(' ', Qt::SkipEmptyParts);
+    auto parts = s.splitRef(' ', SKIP_EMPTY_PARTS);
     if(parts.size() == 0) {
         qWarning() << "TablePLot: Message not understood, expected @set <tabnum> "
                     "or @update";
